<?php

/**
 * This class is responsible to display the settings page for the plugin.
 */
class Woo_Usn_Admin_Settings
{
    /**
     * Function for configure Ultimate SMS Notifications settings.
     */
    public static function configure_woo_usn_settings()
    {
        ?>
		<?php 
        
        if ( isset( $_GET ) && isset( $_GET['tab'] ) && !wp_verify_nonce( '_wpnonce' ) ) {
            $active_tab = filter_input( INPUT_GET, 'tab' );
        } else {
            $active_tab = 'options';
        }
        
        $settings_names = apply_filters( 'woo_usn_settings_names', array(
            'options' => __( 'SMS Notifications', 'ultimate-sms-notifications' ),
            'sms-api' => __( 'SMS Gateways', 'ultimate-sms-notifications' ),
        ) );
        ?>
		<div class="wrap">
			<h1> <?php 
        __( 'Ultimate SMS Notifications for WooCommerce', 'ultimate-sms-notifications' );
        ?></h1>
			<?php 
        settings_errors();
        ?>

			<h2 class="woousn nav-tab-wrapper">
				<?php 
        foreach ( $settings_names as $keyname => $keyvalues ) {
            // phpcs:ignore
            ?>
					<a href="?page=ultimate-sms-notifications&tab=<?php 
            echo  wp_kses( $keyname, array() ) ;
            ?>"
					   class="woousn-tab nav-tab <?php 
            echo  ( $active_tab === $keyname ? 'woousn-tab-active nav-tab-active' : '' ) ;
            ?>"><?php 
            echo  wp_kses( $keyvalues, array() ) ;
            ?></a>
					<?php 
        }
        ?>
			</h2>


			<form method="post" action="options.php">
				<?php 
        
        if ( 'options' === $active_tab ) {
            global  $usn_utility ;
            if ( !$usn_utility::is_wc_active() ) {
                return;
            }
            ?>
					<div class="woousn-options-tab">
						<?php 
            settings_fields( 'woo_usn_options' );
            do_settings_sections( 'woo_usn_options' );
            do_action( 'woo_usn_options' );
            submit_button();
            ?>
					</div>
					<?php 
        } elseif ( 'sms-api' === $active_tab ) {
            self::display_settings_fields();
        }
        
        do_action( 'woo_usn_add_settings_tabs', $active_tab );
        ?>

			</form>
		</div>
		<?php 
    }
    
    public static function display_licence_key_tab()
    {
        // Select Options.
        add_settings_section(
            'woo_usn_licence_page',
            // ID used to identify this section and with which to register options.
            __( 'Set licence informations for Ultimate SMS Notifications for WooCommerce', 'ultimate-sms-notifications' ),
            // Title to be displayed on the administration page.
            __CLASS__ . '::description_for_the_tab_pages',
            // Callback used to render the description of the section.
            'woo_usn_options_licence'
        );
        add_settings_field(
            'woo_usn_licence_key',
            // ID used to identify the field throughout the theme.
            __( 'Licence Key :  ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::display_licence_key_field',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options_licence',
            // The page on which this option will be displayed.
            'woo_usn_licence_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-message-from-orders',
            )
        );
        register_setting( 'woo_usn_options_licence', 'woo_usn_options_licence' );
    }
    
    /**
     * Function to display the options on each tab.
     */
    public static function display_options_on_each_tab()
    {
        /*
         * -----------------------------------------------------------------------------
         * Options.
         * -----------------------------------------------------------------------------
         */
        // Select Options.
        add_settings_section(
            'woo_usn_options_page',
            // ID used to identify this section and with which to register options.
            __( 'Setup your SMS Notifications', 'ultimate-sms-notifications' ),
            // Title to be displayed on the administration page.
            __CLASS__ . '::description_for_the_tab_pages',
            // Callback used to render the description of the section.
            'woo_usn_options'
        );
        add_settings_field(
            'woo_usn_messages_from_orders',
            // ID used to identify the field throughout the theme.
            __( 'Send SMS from orders :  ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::messages_from_orders',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-message-from-orders',
            )
        );
        add_settings_field(
            'woo_usn_message_after_customer_purchase',
            // ID used to identify the field throughout the theme.
            __( 'Send SMS after customer purchase :  ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::after_customer_purchase',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-message-after-customer-purchase',
            )
        );
        add_settings_field(
            'woo_usn_defaults_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send after your customer purchase on your store :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::default_sms_messages',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-defaults-messages',
            )
        );
        add_settings_field(
            'woo_usn_message_after_order_changed',
            // ID used to identify the field throughout the theme.
            __( 'Send SMS after order changed :  ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::after_order_changed',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-message-after-order-changed',
            )
        );
        add_settings_field(
            'woo_usn_completed_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is completed :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_completed',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_processing_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is processing :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_processing',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_cancelled_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is cancelled :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_cancelled',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_refunded_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is refunded :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_refunded',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_on_hold_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is on hold :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_on_hold',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_failed_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is failed :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_failed',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_pending_payment_messages',
            // ID used to identify the field throughout the theme.
            __( 'SMS to send when the order status is pending payment :', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::sms_when_pending_payment',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_sms_to_admin',
            // ID used to identify the field throughout the theme.
            __( 'Send SMS to shop owner/manager after an order completed :  ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::messages_to_admin',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                // The array of arguments to pass to the callback. In this case, just a description.
                '',
            )
        );
        add_settings_field(
            'woo_usn_admin_messages_template',
            // ID used to identify the field throughout the theme.
            __( 'SMS that shop owner/manager receive after a completed order : ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::display_shop_admin_template_messages',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-admin-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_admin_numbers',
            // ID used to identify the field throughout the theme.
            __( 'Phone number of the store owner/manager : ', 'ultimate-sms-notifications' ),
            // The label to the left of the option interface element.
            __CLASS__ . '::display_shop_admin_numbers',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-admin-completed-messages',
            )
        );
        add_settings_field(
            'woo_usn_sms_consent',
            // ID used to identify the field throughout the theme.
            __( 'Get customer permission before sending SMS : ', 'ultimate-sms-notifications' ),
            __CLASS__ . '::display_consent_sms',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                // The array of arguments to pass to the callback. In this case, just a description.
                '',
            )
        );
        add_settings_field(
            'woo_usn_sms_consent_text_to_display',
            // ID used to identify the field throughout the theme.
            '',
            // The label to the left of the option interface element.
            __CLASS__ . '::display_consent_text_to_display',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                'class' => 'woo-usn-customer-consent',
            )
        );
        add_settings_field(
            'woo_usn_options_tags',
            // ID used to identify the field throughout the theme.
            '',
            // The label to the left of the option interface element.
            __CLASS__ . '::display_options_tags',
            // The name of the function responsible for rendering the option interface.
            'woo_usn_options',
            // The page on which this option will be displayed.
            'woo_usn_options_page',
            // The name of the section to which this field belongs.
            array(
                // The array of arguments to pass to the callback. In this case, just a description.
                '',
            )
        );
        do_action( 'woo_usn_options_settings_field' );
        register_setting( 'woo_usn_options', 'woo_usn_options' );
    }
    
    public static function display_consent_sms()
    {
        $options = get_option( 'woo_usn_options' );
        $checked = 1;
        if ( !isset( $options['woo_usn_sms_consent'] ) ) {
            $checked = 0;
        }
        homescript_input_fields( 'woo_usn_options[woo_usn_sms_consent]', array(
            'type'        => 'checkbox',
            'label'       => __( 'Enable/Disable', 'ultimate-sms-notifications' ),
            'description' => __( '<br/>By enabling, the customer decides whether  to receive any kinds of SMS.', 'ultimate-sms-notifications' ),
        ), $checked );
    }
    
    public static function display_consent_text_to_display()
    {
        $options = get_option( 'woo_usn_options' );
        $settings = array(
            'textarea_name' => 'woo_usn_sms_consent_text_to_display',
            'media_buttons' => false,
        );
        $content = __( 'I would receive any kind of SMS on my phone number.', 'ultimmate-sms-notifications' );
        if ( !empty($options['woo_usn_sms_consent_text_to_display']) ) {
            $content = $options['woo_usn_sms_consent_text_to_display'];
        }
        wp_editor( $content, 'woo_usn_sms_consent_text_to_display', $settings );
    }
    
    /**
     * Display admin template messages fields.
     */
    public static function display_shop_admin_template_messages()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_admin_messages_template]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_admin_messages_template'],
        ) );
    }
    
    public static function display_vendor_template_messages_premium_only()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_vendor_messages_template]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_vendor_messages_template'],
        ) );
    }
    
    /**
     * Display settings fields.
     */
    public static function display_settings_fields()
    {
        do_action( 'woo_usn_options_before_sms_api_fields' );
        $display_settings = apply_filters( 'woo_usn_display_sms_api', true );
        
        if ( $display_settings ) {
            ?>
			<div class="woousn-settings-panel usn-center-panel-values" id="usn-contents">
				<h3><?php 
            esc_html_e( 'Configure SMS API', 'ultimate-sms-notifications' );
            ?></h3>
				<?php 
            esc_html_e( 'Please provide API Credentials in order to be able to use Ultimate SMS Notifications into your store.', 'ultimate-sms-notifications' );
            Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
            Woo_Usn_UI_Fields::format_html_fields( '<br/>Choose the suitable SMS API you want to use : ' );
            $options = get_option( 'woo_usn_api_choosed' );
            $items = apply_filters( 'woo_usn_api_choosed', array( 'Telesign', 'Twilio' ) );
            Woo_Usn_UI_Fields::format_html_fields( "<select id='woo_usn_api_to_choose' name='woo_usn_api_choosed'>" );
            foreach ( $items as $item ) {
                $selected = ( $options === $item ? 'selected="selected"' : '' );
                Woo_Usn_UI_Fields::format_html_fields( "<option value='{$item}' {$selected}>{$item}</option>" );
            }
            Woo_Usn_UI_Fields::format_html_fields( '</select>' );
            ?>
				<div id="woo_usn_api_telesign" class="wrap" style="display : block;" data-name="telesign">
					<?php 
            Woo_Usn_UI_Fields::format_html_fields( 'Set Telesign by providing information necessary in the fields below.<br/>' );
            Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
            homescript_input_fields( 'woo_usn_telesign_custom_id', array(
                'type'        => 'text',
                'label'       => '<strong>' . __( ' Customer ID : ', 'ultimate-sms-notifications' ) . '</strong>',
                'input_class' => array( 'woousn-text-customs-api' ),
                'placeholder' => 'FFFFFFFF-EEEE-DDDD-1234-AB1234567890',
                'required'    => true,
                'default'     => esc_attr( get_option( 'woo_usn_telesign_custom_id' ) ),
                'description' => __( "You can retrieve it from your <a href='https://portal.telesign.com/login'>Telesign Portal</a>.", 'ultimate-sms-notifications' ),
            ) );
            Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
            homescript_input_fields( 'woo_usn_telesign_api_key', array(
                'type'        => 'text',
                'label'       => '<strong>' . __( ' API Key : ', 'ultimate-sms-notifications' ) . '</strong>',
                'input_class' => array( 'woousn-text-customs-api' ),
                'required'    => true,
                'placeholder' => 'EXAMPLE----TE8sTgg45yusumoN6BYsBVkh+yRJ5czgsnCehZaOYldPJdmFh6NeX8kunZ2zU1YWaUw/0wV6xfw==',
                'default'     => esc_attr( get_option( 'woo_usn_telesign_api_key' ) ),
                'description' => __( "You can retrieve it from your <a href='https://portal.telesign.com/login'>Telesign Portal</a>.", 'ultimate-sms-notifications' ),
            ) );
            Woo_Usn_UI_Fields::format_html_fields( "You will need a Customer ID and API Key in order to use TeleSign’s API. If you already have an account you can retrieve\n\t\tthem from your account dashboard within the  <a href='https://portal.telesign.com/login'>Portal</a>. If you have not signed up\n\t\tyet, sign up <a href='https://portal.telesign.com/signup'>here</a>." );
            ?>
				</div>

				<div id="woo_usn_api_twilio" class="wrap" style="display : none;" data-name="twilio">
					<?php 
            Woo_Usn_UI_Fields::format_html_fields( 'Set Twilio by providing information necessary in the fields below.<br/>' );
            echo  '<br/>' ;
            homescript_input_fields( 'woo_usn_twilio_account_sid', array(
                'type'        => 'text',
                'label'       => '<strong>' . __( ' Account SID : ', 'ultimate-sms-notifications' ) . '</strong>',
                'input_class' => array( 'woousn-text-customs-api' ),
                'placeholder' => 'ACXXXXXXXXXXXXXXXXXX',
                'required'    => true,
                'default'     => esc_attr( get_option( 'woo_usn_twilio_account_sid' ) ),
                'description' => __( "You can retrieve it from your <a href='https://www.twilio.com/referral/bc0mtq'>Twilio Console</a>.", 'ultimate-sms-notifications' ),
            ) );
            echo  '<br/>' ;
            homescript_input_fields( 'woo_usn_twilio_auth_token', array(
                'type'        => 'text',
                'label'       => '<strong>' . __( '  Auth Token :  ', 'ultimate-sms-notifications' ) . '</strong>',
                'input_class' => array( 'woousn-text-customs-api' ),
                'placeholder' => 'YYYYYYYYYYYYYYYY',
                'required'    => true,
                'default'     => esc_attr( get_option( 'woo_usn_twilio_auth_token' ) ),
                'description' => __( "You can retrieve it from your <a href='https://www.twilio.com/referral/bc0mtq'>Twilio Console</a>.", 'ultimate-sms-notifications' ),
            ) );
            echo  '<br/>' ;
            homescript_input_fields( 'woo_usn_twilio_phone_number', array(
                'type'        => 'text',
                'label'       => '<strong>' . __( '  Twilio Phone Number :  ', 'ultimate-sms-notifications' ) . '</strong>',
                'input_class' => array( 'woousn-text-customs-api' ),
                'placeholder' => '+1234567890',
                'required'    => true,
                'default'     => esc_attr( get_option( 'woo_usn_twilio_phone_number' ) ),
                'description' => __( "You can retrieve it from your <a href='https://www.twilio.com/referral/bc0mtq'>Twilio Console</a>.", 'ultimate-sms-notifications' ),
            ) );
            _e( "You will need a Account SID and Auth Token in order to use Twilio's API. If you already have an account you can retrieve\n\t\t\tthem from your Twilio Console within the  <a href='www.twilio.com/referral/bc0mtq'>Console</a>. If you have not signed up\n\t\t\tyet, sign up <a href='www.twilio.com/referral/bc0mtq'>here</a>.", 'ultimate-sms-notifications' );
            ?>
				</div>
				<?php 
            do_action( 'woo_usn_options_before_saving_sms_api_fields' );
            ?>
			</div>
			<div id="woo_usn_testing_sections" class="wrap">
				<?php 
            submit_button(
                __( 'Save API Credentials', 'ultimate-sms-notifications' ),
                'primary',
                '',
                false,
                array(
                'id' => 'woo_usn_saving',
            )
            );
            echo  '&nbsp' ;
            submit_button(
                __( 'Delete API Credentials ', 'ultimate-sms-notifications' ),
                'primary',
                '',
                false,
                array(
                'id' => 'woo_usn_deleting',
            )
            );
            ?>
			</div>
			<?php 
            do_action( 'woo_usn_options_after_sms_api_fields' );
        }
        
        ?>
		<br/>
		<div class="woousn-cl-loader" style="display: none;"></div>
		<div class="woo_usn_modal_body"></div>
		<span class="woo_usn_panels" id="woo_usn_saving_status" style="display:none;"></span>
		<div id="woo_usn_testing_sections" class="wrap">
			<h3><?php 
        esc_html_e( 'Status', 'ultimate-sms-notifications' );
        ?></h3>
			<?php 
        esc_html_e( 'Send test messages to a number to find out if your API credentials are working properly.', 'ultimate-sms-notifications' );
        ?>
			<br/>

			<br/>
			<?php 
        homescript_input_fields( 'woo_usn_testing_numbers', array(
            'required'    => true,
            'label'       => '<strong>' . __( 'Testing numbers : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woo-usn-testing-numbers', 'woousn-text-customs' ),
        ) );
        homescript_input_fields( 'woo_usn_testing_messages', array(
            'type'        => 'textarea',
            'required'    => true,
            'label'       => '<strong>' . __( 'Testing messages : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-textarea', 'woo-usn-testing-messages' ),
            'placeholder' => __( 'Type your message here.', 'ultimate-sms-notifications' ),
        ) );
        homescript_input_fields( 'woo_usn_testing_status', array(
            'type'        => 'textarea',
            'required'    => true,
            'id'          => 'woo-usn-response-status',
            'input_class' => array( 'woousn-textarea', 'woo-usn-response-status' ),
            'placeholder' => __( 'Type your message here.', 'ultimate-sms-notifications' ),
        ) );
        submit_button(
            __( 'Send Test SMS', 'ultimate-sms-notifications' ),
            'primary',
            '',
            false,
            array(
            'id' => 'woo_usn_testing',
        )
        );
        ?>
		</div>
		<br/>
		<div class="woousn-cl-status" style="display: none;"></div>

		<div class="woousn-body-cl-status">
		</div>
		</div>
		<?php 
    }
    
    /**
     * Display checkbox for sending messages to admin.
     */
    public static function messages_to_admin()
    {
        $options = get_option( 'woo_usn_options' );
        $checked = 0;
        if ( !empty($options['woo_usn_sms_to_admin']) ) {
            $checked = 1;
        }
        homescript_input_fields( 'woo_usn_options[woo_usn_sms_to_admin]', array(
            'type'        => 'checkbox',
            'label'       => __( 'Enable/Disable', 'ultimate-sms-notifications' ),
            'description' => __( '<br/>By enabling, the shop owner/manager phone number will receive an automated SMS, when any purchase is made on the shop.', 'ultimate-sms-notifications' ),
        ), $checked );
    }
    
    /**
     * Setting pending payment orders status by sms.
     */
    public static function messages_from_orders()
    {
        $options = get_option( 'woo_usn_options' );
        $checked = 0;
        if ( !empty($options['woo_usn_messages_from_orders']) ) {
            $checked = 1;
        }
        homescript_input_fields( 'woo_usn_options[woo_usn_messages_from_orders]', array(
            'type'        => 'checkbox',
            'label'       => __( 'Enable/Disable', 'ultimate-sms-notifications' ),
            'description' => __( '<br/>By enabling, you can send manually from your order , an SMS directly to the customer concerned.', 'ultimate-sms-notifications' ),
        ), $checked );
    }
    
    /**
     * Display fields where admin put his phone numbers.
     */
    public static function display_shop_admin_numbers()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_admin_numbers]', array(
            'type'        => 'text',
            'required'    => true,
            'input_class' => array( 'woousn-text-customs' ),
            'placeholder' => '+1234567890',
        ), esc_attr( $options['woo_usn_admin_numbers'] ) );
    }
    
    public static function display_licence_key_field()
    {
        $options = get_option( 'woo_usn_options_licence' );
        homescript_input_fields( 'woo_usn_options_licence[woo_usn_licence_key]', array(
            'type'        => 'text',
            'required'    => true,
            'input_class' => array( 'input-text woousn-text-customs-api' ),
            'placeholder' => 'XXXXXXXXXXXXXXXXXXXXXX',
            'wrapper'     => false,
        ), esc_attr( $options['woo_usn_licence_key'] ) );
    }
    
    /**
     * Function for setting who allows to send SMS after customer purchase.
     */
    public static function after_customer_purchase()
    {
        $options = get_option( 'woo_usn_options' );
        $checked = 0;
        if ( !empty($options['woo_usn_message_after_customer_purchase']) ) {
            $checked = 1;
        }
        homescript_input_fields( 'woo_usn_options[woo_usn_message_after_customer_purchase]', array(
            'type'        => 'checkbox',
            'label'       => __( 'Enable/Disable', 'ultimate-sms-notifications' ),
            'description' => __( '<br/>By enabling, an automated SMS will be send to the customer who have purchased on your store.', 'ultimate-sms-notifications' ),
        ), $checked );
    }
    
    /**
     * Function for setting who allows to send SMS after order changed.
     */
    public static function after_order_changed()
    {
        $options = get_option( 'woo_usn_options' );
        $checked = 0;
        if ( !empty($options['woo_usn_message_after_order_changed']) ) {
            $checked = 1;
        }
        homescript_input_fields( 'woo_usn_options[woo_usn_message_after_order_changed]', array(
            'type'        => 'checkbox',
            'label'       => __( 'Enable/Disable', 'ultimate-sms-notifications' ),
            'description' => __( '<br/>By enabling, an automated SMS will be send to the customer when his order status changed.', 'ultimate-sms-notifications' ),
        ), $checked );
    }
    
    /**
     * Display options tags.
     */
    public static function display_options_tags( $is_vendor = false )
    {
        global  $usn_utility ;
        Woo_Usn_UI_Fields::format_html_fields( '<p> Use these tags to customize your message : </p>' );
        
        if ( !isset( $is_vendor['is_vendor'] ) ) {
            foreach ( $usn_utility::get_list_of_tag_names() as $tag_names ) {
                Woo_Usn_UI_Fields::format_html_fields( '<strong style="background-color : #5ce1e6;">' . str_replace( '/', '', $tag_names ) . ',</strong> ' );
            }
        } else {
            Woo_Usn_UI_Fields::format_html_fields( '<strong style="background-color : #5ce1e6;">%vendor_name%</strong>, <strong style="background-color : #5ce1e6;">%vendor_products_names%</strong>' );
        }
    
    }
    
    /**
     * Display the description for settings tab pages.
     */
    public static function description_for_the_tab_pages()
    {
        esc_html_e( 'You can configure options you want to use into this plugin here.', 'ultimate-sms-notifications' );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_completed()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_completed_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_completed_messages'],
        ) );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_processing()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_processing_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_processing_messages'],
        ) );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_cancelled()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_cancelled_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_cancelled_messages'],
        ) );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_on_hold()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_on_hold_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_on_hold_messages'],
        ) );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_pending_payment()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_pending_payment_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_pending_payment_messages'],
        ) );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_failed()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_failed_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_failed_messages'],
        ) );
    }
    
    /**
     * Display a field for set the messages for changement of order status.
     */
    public static function sms_when_refunded()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( 'woo_usn_options[woo_usn_refunded_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_refunded_messages'],
        ) );
    }
    
    /**
     * Message who is sent to user when his orders is in pending payment status.
     */
    public static function default_sms_messages()
    {
        $options = get_option( 'woo_usn_options' );
        homescript_input_fields( ' woo_usn_options[woo_usn_defaults_messages]', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woo_usn_messages_to_send', 'woousn-textarea' ),
            'placeholder' => __( 'Please put the default sms to send.', 'ultimate-sms-notifications' ),
            'default'     => $options['woo_usn_defaults_messages'],
        ) );
    }
    
    /**
     * Add SMS Gateway to the list.
     *
     * @param array $api_name SMS Gateway lists.
     *
     * @return array
     */
    public static function add_external_api( $api_name )
    {
        $list = array( 'Kivalo', 'WA API' );
        $api_name = array_merge( $api_name, $list );
        return $api_name;
    }
    
    /**
     * Display external SMS Gateway fields.
     *
     * @return void
     */
    public static function add_external_api_fields()
    {
        ?>
		<div id="woo_usn_api_kivalo" class="wrap" data-name="kivalo" style="display:none;">
			<?php 
        Woo_Usn_UI_Fields::format_html_fields( 'Set Kivalo by providing information necessary in the fields below.<br/>' );
        Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
        homescript_input_fields( 'woo_usn_kivalo_from_number', array(
            'type'        => 'text',
            'label'       => '<strong>' . __( 'Kivalo From Phone number : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-text-customs-api' ),
            'placeholder' => '233xxxxxxx',
            'required'    => true,
            'default'     => esc_attr( get_option( 'woo_usn_kivalo_from_phone_number' ) ),
            'description' => __( "You can retrieve it from your <a href='https://sms.kivalosolutions.com'>Kivalo account</a>.", 'ultimate-sms-notifications' ),
        ) );
        Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
        homescript_input_fields( 'woo_usn_kivalo_api_key', array(
            'type'        => 'text',
            'label'       => '<strong>' . __( 'Kivalo API Key : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-text-customs-api' ),
            'required'    => true,
            'placeholder' => '000000xxxxxxxxxx',
            'default'     => esc_attr( get_option( 'woo_usn_kivalo_api_key' ) ),
            'description' => __( "You can retrieve it from your <a href='https://sms.kivalosolutions.com'>Kivalo account</a>.", 'ultimate-sms-notifications' ),
        ) );
        Woo_Usn_UI_Fields::format_html_fields( "You will need a Kivalo From Phone Number and API Key in order to use Kivalo’s API. If you already have an account you can retrieve\n\t\tthem from your account dashboard within the  <a href='https://sms.kivalosolutions.com'>Portal</a>. If you have not signed up\n\t\tyet, sign up <a href='https://sms.kivalosolutions.com/signup'>here</a>." );
        ?>
		</div>

		<div id="woo_usn_api_waapi" class="wrap" data-name="kivalo" style="display:none;">
			<?php 
        Woo_Usn_UI_Fields::format_html_fields( 'Set Waapi by providing information necessary in the fields below.<br/>' );
        Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
        homescript_input_fields( 'woo_usn_waapi_client_id', array(
            'type'        => 'text',
            'label'       => '<strong>' . __( 'Waapi Client ID : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-text-customs-api' ),
            'placeholder' => '0ABCxxxxxxxxxx',
            'required'    => true,
            'default'     => esc_attr( get_option( 'woo_usn_waapi_client_id' ) ),
            'description' => __( "You can retrieve it from your <a href='https://checkout.waapi.co/api/affurl/0elOEJ0M4As1ENZ1n/HLKBxj10HmbMiA8o?target=Vpas2KguYoFAg08o'>Waapi account</a>.", 'ultimate-sms-notifications' ),
        ) );
        Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
        homescript_input_fields( 'woo_usn_waapi_instance_id', array(
            'type'        => 'text',
            'label'       => '<strong>' . __( 'Waapi Instance ID : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-text-customs-api' ),
            'required'    => true,
            'placeholder' => '000000xxxxxxxxxx',
            'default'     => esc_attr( get_option( 'woo_usn_waapi_instance_id' ) ),
            'description' => __( "You can retrieve it from your <a href='https://checkout.waapi.co/api/affurl/0elOEJ0M4As1ENZ1n/HLKBxj10HmbMiA8o?target=Vpas2KguYoFAg08o'>Waapi account</a>.", 'ultimate-sms-notifications' ),
        ) );
        Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
        homescript_input_fields( 'woo_usn_waapi_domain_url', array(
            'type'        => 'text',
            'label'       => '<strong>' . __( 'Waapi Domain URL : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-text-customs-api' ),
            'required'    => true,
            'placeholder' => 'https://apiv3.waapi.co',
            'default'     => esc_attr( get_option( 'woo_usn_waapi_domain_url' ) ),
            'description' => __( "You can retrieve it from your <a href='https://checkout.waapi.co/api/affurl/0elOEJ0M4As1ENZ1n/HLKBxj10HmbMiA8o?target=Vpas2KguYoFAg08o'>Waapi account</a>.", 'ultimate-sms-notifications' ),
        ) );
        Woo_Usn_UI_Fields::format_html_fields( '<br/>' );
        Woo_Usn_UI_Fields::format_html_fields( "You will need a Waapi Client ID and Instance ID in order to send Whatsapp messages. If you already have an account you can retrieve\n\t\tthem from your account dashboard or watching this video <a href ='https://www.youtube.com/watch?v=zoaGETg0eZY'>here</a> to see how to do." );
        ?>
		</div>
		<?php 
    }
    
    /**
     * This allows to send SMS from the dashboard.
     *
     * @return void
     */
    public static function send_sms()
    {
        ?>
		<div>
			<h3><?php 
        Woo_Usn_UI_Fields::format_html_fields( 'Send SMS' );
        ?></h3>
		</div>
		<div id="sms-block">
			<?php 
        homescript_input_fields( 'woo_usn_testing_numbers', array(
            'required'    => true,
            'label'       => '<strong>' . __( 'Phone Number : ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woo-usn-testing-numbers', 'woousn-text-customs' ),
        ) );
        homescript_input_fields( 'woo_usn_testing_messages', array(
            'type'        => 'textarea',
            'required'    => true,
            'label'       => '<strong>' . __( 'Messages: ', 'ultimate-sms-notifications' ) . '</strong>',
            'input_class' => array( 'woousn-textarea', 'woo-usn-testing-messages' ),
            'placeholder' => __( 'Type your message here.', 'ultimate-sms-notifications' ),
        ) );
        homescript_input_fields( 'woo_usn_testing_status', array(
            'type'        => 'textarea',
            'required'    => true,
            'id'          => 'woo-usn-response-status',
            'input_class' => array( 'woousn-textarea', 'woo-usn-response-status' ),
            'placeholder' => __( 'Type your message here.', 'ultimate-sms-notifications' ),
        ) );
        submit_button(
            __( 'Send Test SMS', 'ultimate-sms-notifications' ),
            'primary',
            '',
            false,
            array(
            'id' => 'woo_usn_testing',
        )
        );
        ?>
		</div>
		<br/>
		<div class="woousn-cl-status" style="display: none;"></div>

		<div class="woousn-body-cl-status">
		</div>
		</div>
		<?php 
    }

}