<?php

/**
 * This class handle all the custom post types registered with the plugins.
 */
class Woo_Usn_CPT
{
    /**
     * This function loads the plugin CPT.
     *
     * @return void
     */
    public static function define_custom_post_type()
    {
        $sms_labels = array(
            'name'               => __( 'Bulk SMS', 'ultimate-sms-notifications' ),
            'singular_name'      => __( 'Bulk SMS', 'ultimate-sms-notifications' ),
            'add_new'            => __( 'New Bulk SMS', 'ultimate-sms-notifications' ),
            'add_new_item'       => __( 'New Bulk SMS', 'ultimate-sms-notifications' ),
            'edit_item'          => __( 'Edit Bulk SMS', 'ultimate-sms-notifications' ),
            'new_item'           => __( 'New Bulk SMS', 'ultimate-sms-notifications' ),
            'view_item'          => __( 'View Bulk SMS', 'ultimate-sms-notifications' ),
            'search_items'       => __( 'Search Bulk SMS', 'ultimate-sms-notifications' ),
            'not_found'          => __( 'No Bulk SMS found', 'ultimate-sms-notifications' ),
            'not_found_in_trash' => __( 'No Bulk SMS in the trash', 'ultimate-sms-notifications' ),
            'menu_name'          => __( 'Bulk SMS', 'ultimate-sms-notifications' ),
        );
        $sms_args = array(
            'labels'              => $sms_labels,
            'hierarchical'        => false,
            'description'         => __( 'Bulk SMS', 'ultimate-sms-notifications' ),
            'supports'            => array( 'title' ),
            'public'              => false,
            'show_ui'             => true,
            'show_in_menu'        => false,
            'show_in_nav_menus'   => false,
            'publicly_queryable'  => false,
            'exclude_from_search' => true,
            'has_archive'         => false,
            'query_var'           => false,
            'can_export'          => true,
        );
        register_post_type( 'woo_usn-sms-panel', $sms_args );
        $contact_list_labels = array(
            'name'               => __( 'Contact List', 'ultimate-sms-notifications' ),
            'singular_name'      => __( 'Contact List', 'ultimate-sms-notifications' ),
            'add_new'            => __( 'New Contact List', 'ultimate-sms-notifications' ),
            'add_new_item'       => __( 'New Contact List', 'ultimate-sms-notifications' ),
            'edit_item'          => __( 'Edit Contact List', 'ultimate-sms-notifications' ),
            'new_item'           => __( 'New Contact List', 'ultimate-sms-notifications' ),
            'view_item'          => __( 'View Contact List', 'ultimate-sms-notifications' ),
            'search_items'       => __( 'Search Contact List', 'ultimate-sms-notifications' ),
            'not_found'          => __( 'No Contact List found', 'ultimate-sms-notifications' ),
            'not_found_in_trash' => __( 'No Contact List in the trash', 'ultimate-sms-notifications' ),
            'menu_name'          => __( 'Contact List', 'ultimate-sms-notifications' ),
        );
        $contact_list_args = array(
            'labels'              => $contact_list_labels,
            'hierarchical'        => false,
            'description'         => __( 'Contact Lists', 'ultimate-sms-notifications' ),
            'supports'            => array( 'title' ),
            'public'              => false,
            'show_ui'             => true,
            'show_in_menu'        => false,
            'show_in_nav_menus'   => false,
            'publicly_queryable'  => false,
            'exclude_from_search' => true,
            'has_archive'         => false,
            'query_var'           => false,
            'can_export'          => true,
        );
        register_post_type( 'woo_usn-list', $contact_list_args );
    }
    
    /**
     * Force plugin CPT to use 1 column layout into the dashboard.
     *
     * @return int
     */
    public static function set_one_column_for_cpt( $column )
    {
        return 1;
    }
    
    /**
     * This function add metabox in other to use it with the plugin.
     *
     * @return void
     */
    public static function add_metabox()
    {
        add_meta_box(
            'woousn-bulk-sms',
            __( 'Compose Bulk SMS', 'ultimate-sms-notifications' ),
            __CLASS__ . '::compose_bulk_sms',
            'woo_usn-sms-panel'
        );
        add_meta_box(
            'woousn-customer-list',
            __( 'Contact List', 'ultimate-sms-notifications' ),
            __CLASS__ . '::compose_customer_list',
            'woo_usn-list'
        );
    }
    
    /**
     * This function save the bulk SMS data to the db.
     *
     * @param int $post_id Bulk SMS ID.
     *
     * @return void
     */
    public static function send_bulk_sms( $post_id )
    {
        $posted_data = filter_input_array( INPUT_POST );
        
        if ( isset( $posted_data['woo_usn_bs_nonce_fields'] ) ) {
            $nonce = $posted_data['woo_usn_bs_nonce_fields'];
            
            if ( wp_verify_nonce( $nonce, 'woo_usn_bs_nonce' ) ) {
                $data = $posted_data['woo-usn'];
                $data['bulk-sms-status'] = 'started';
                update_post_meta( $post_id, 'woo-usn-bulk-data', $data );
            }
        
        }
    
    }
    
    /**
     * This function save the customer list data to the db.
     *
     * @param int $post_id Customer List ID.
     *
     * @return void
     */
    public static function save_customer_list( $post_id )
    {
        $posted_data = filter_input_array( INPUT_POST );
        
        if ( isset( $posted_data['woo_usn_cl_nonce_fields'] ) ) {
            $nonce = $posted_data['woo_usn_cl_nonce_fields'];
            
            if ( wp_verify_nonce( $nonce, 'woo_usn_cl_nonce' ) ) {
                $data = $posted_data['woo-usn'];
                update_post_meta( $post_id, 'woo-usn-customer-list', $data );
            }
        
        }
    
    }
    
    /**
     * This method helps to compose easily the bulk sms.
     *
     * @return void
     */
    public static function compose_bulk_sms( $sms )
    {
        global  $usn_utility ;
        if ( !$usn_utility::is_wc_active() ) {
            return;
        }
        $post_id = $sms->ID;
        $bulk_sms_data = get_post_meta( $post_id, 'woo-usn-bulk-data', true );
        wp_nonce_field( 'woo_usn_bs_nonce', 'woo_usn_bs_nonce_fields' );
        echo  "<div style='padding: 10px; background-color:whitesmoke; height:auto;' class='woousn_customer_list'>" ;
        $customer_list_array = Woo_Usn_Customer_List::get_all_customers_lists();
        $way_to_schedule = 'once';
        if ( isset( $bulk_sms_data['schedule-sms'] ) ) {
            $way_to_schedule = $bulk_sms_data['schedule-sms'];
        }
        $customer_list_selected = array_key_first( $customer_list_array );
        if ( isset( $bulk_sms_data['bulk-sms-receivers'] ) ) {
            $customer_list_selected = $bulk_sms_data['bulk-sms-receivers'];
        }
        $sending_start_date = strftime( '%Y/%m/%d %H:%m' );
        $sending_end_date = $sending_start_date;
        if ( isset( $bulk_sms_data['schedule-start-date'] ) ) {
            $sending_start_date = $bulk_sms_data['schedule-start-date'];
        }
        if ( isset( $bulk_sms_data['schedule-end-date'] ) ) {
            $sending_end_date = $bulk_sms_data['schedule-end-date'];
        }
        $bulk_sms_to_send = "<span class='woo-usn-display-textarea' style='float: none !important;'>";
        $message_to_send = array();
        if ( isset( $bulk_sms_data['messages-to-send'] ) ) {
            $message_to_send = $bulk_sms_data['messages-to-send'];
        }
        // We build the different message block used to send easily message to customers.
        foreach ( $message_to_send as $message ) {
            $random_string = $usn_utility::generate_random_string();
            $bulk_sms_to_send .= '<span class="woo-usn-bulk-sms-index" style="display: grid;" data-id="' . $random_string . '">
            <textarea class="woo-usn-textarea-' . $random_string . ' woo_usn_textarea_text" rows="5" style="width: 500px;" name="woo-usn[messages-to-send][' . $random_string . ']">' . $message . '</textarea><br/><button class="button button-primary woo-usn-remove-prev-block" data-id="' . $random_string . '" style="width: 40% !important;">' . __( 'Remove message block', 'ultimate-sms-notifications' ) . '</button><br/></span><br/>';
        }
        $bulk_sms_to_send .= '<span class="woo-usn-bulk-sms-add-more-message"><button class="button button-primary woo-usn-add-more-message"> Add message block</button></span>';
        $bulk_sms_to_send .= '</span>';
        $upgrade_message = 'Upgrade <a target="__blank" href="' . admin_url( 'admin.php?page=ultimate-sms-notifications-pricing' ) . '" >here</a>';
        $schedule_types = array(
            'once'        => __( 'Once : Bulk SMS will be sent only today', 'ultimate-sms-notifications' ),
            'daily-pro'   => __( 'Daily : Bulk SMS will be sent each days <strong>(Pro Features)</strong>.' . $upgrade_message, 'ultimate-sms-notifications' ),
            'weekly-pro'  => __( 'Weekly : Bulk SMS will be sent each weeks <strong>(Pro Features)</strong>.' . $upgrade_message, 'ultimate-sms-notifications' ),
            'monthly-pro' => __( 'Monthly : Bulk SMS will be sent each months <strong>(Pro Features)</strong>.' . $upgrade_message, 'ultimate-sms-notifications' ),
        );
        $table_args = array(
            array(
            'label'       => __( 'Bulk SMS Start Sending :', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'content'     => homescript_input_fields( 'woo-usn[schedule-start-date]', array(
            'type'        => 'text',
            'input_class' => array( 'woo-usn-datetime-local' ),
            'return'      => true,
            'id'          => 'woo-usn-start-date',
        ), $sending_start_date ),
        ),
            array(
            'label'       => __( 'Bulk SMS End Sending :', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'content'     => homescript_input_fields( 'woo-usn[schedule-end-date]', array(
            'type'        => 'text',
            'input_class' => array( 'woo-usn-datetime-local' ),
            'return'      => true,
            'id'          => 'woo-usn-end-date',
        ), $sending_end_date ),
        ),
            array(
            'label'       => __( 'Bulk SMS Sending List :', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'description' => __( 'Which customer list must be used to send the Bulk SMS ?', 'ultimate-sms-notifications' ),
            'content'     => homescript_input_fields( 'woo-usn[bulk-sms-receivers]', array(
            'type'        => 'select',
            'required'    => true,
            'options'     => $customer_list_array,
            'label_class' => 'woo_usn_bs_label',
            'return'      => true,
        ), $customer_list_selected ),
        ),
            array(
            'label'       => __( 'Bulk SMS Sending Intervals :', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'description' => __( 'How would you like to plan for sending bulk SMS ?', 'ultimate-sms-notifications' ),
            'content'     => homescript_input_fields( 'woo-usn[schedule-sms]', array(
            'type'     => 'radio',
            'required' => true,
            'options'  => apply_filters( 'woo_usn_bulk_sms_schedules_type', $schedule_types ),
            'default'  => 'once',
            'return'   => true,
        ), $way_to_schedule ),
        ),
            array(
            'label'       => __( 'Bulk SMS Message to Send :', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'description' => __( 'Type your message here :  ', 'ultimate-sms-notifications' ),
            'content'     => $bulk_sms_to_send,
        )
        );
        homescript_input_table( 'bulk-sms-sender', apply_filters( 'woo_usn_bulk_sms_sender_options', $table_args ) );
        $bulk_sms_status = 'started';
        if ( isset( $bulk_sms_data['bulk-sms-status'] ) ) {
            $bulk_sms_status = $bulk_sms_data['bulk-sms-status'];
        }
        echo  sprintf( "<input name='woo-usn[bulk-sms-status]' value='%s' type='hidden'>", esc_attr( $bulk_sms_status ) ) ;
    }
    
    /**
     *
     * This function give the ability to easily create the contact list who
     * will help to send the bulk SMS.
     *
     * @param mixed $customer_list WP Post ID.
     * @return void
     */
    public static function compose_customer_list( $customer_list )
    {
        global  $usn_utility ;
        if ( !$usn_utility::is_wc_active() ) {
            return;
        }
        $customer_list_id = $customer_list->ID;
        $customer_list_data = get_post_meta( $customer_list_id, 'woo-usn-customer-list', true );
        $customer_list_relationship = $usn_utility::get_relationship();
        $customer_list_relationship_selected = 'and';
        if ( isset( $customer_list_data['customer-list-relationship'] ) ) {
            $customer_list_relationship_selected = $customer_list_data['customer-list-relationship'];
        }
        $customer_list_search_type = 'by-id';
        if ( isset( $customer_list_data['customer-list-search-type'] ) ) {
            $customer_list_search_type = $customer_list_data['customer-list-search-type'];
        }
        $customer_list_by_id = '';
        if ( isset( $customer_list_data['customer-list-by-id'] ) ) {
            $customer_list_by_id = $customer_list_data['customer-list-by-id'];
        }
        if ( $customer_list_data == '' ) {
            $customer_list_data = array();
        }
        ?>
		<script>
			var woo_usn_cl_type = "<?php 
        echo  esc_attr( $customer_list_search_type ) ;
        ?>";
			woo_usn_ajax_object.cl_list_data =
		<?php 
        unset( $customer_list_data['customer-list-relationship'] );
        unset( $customer_list_data['customer-list-search-type'] );
        unset( $customer_list_data['customer-list-by-id'] );
        echo  wp_json_encode( array_map( 'sanitize_post', $customer_list_data ), JSON_UNESCAPED_SLASHES ) ;
        ?>;
		</script>
		<form class="woousn_customer_list" method="post">
			<?php 
        wp_nonce_field( 'woo_usn_cl_nonce', 'woo_usn_cl_nonce_fields' );
        $table_args = array(
            array(
            'label'       => __( 'Extraction mode', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'tr_class'    => 'woo-usn-customer-list-label',
            'description' => __( 'How would you want to retrieve Phone Numbers for the Contact List?', 'ultimate-sms-notifications' ),
            'content'     => homescript_input_fields( 'woo-usn[customer-list-search-type]', array(
            'type'     => 'radio',
            'required' => true,
            'options'  => array(
            'by-id'   => __( 'By ID : Phone Numbers will be retrieved based on the order ID', 'ultimate-sms-notifications' ),
            'dynamic' => __( 'Dynamically : Phone Numbers will be retrieved based on some parameters', 'ultimate-sms-notifications' ),
        ),
            'return'   => true,
        ), $customer_list_search_type ),
        ),
            array(
            'label'       => __( 'Extraction by ID', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'tr_class'    => 'woo-usn-customer-list-manual',
            'description' => __( 'Provide the order ID, we must use for retrieve the Phone Numbers', 'ultimate-sms-notifications' ),
            'content'     => homescript_input_fields( 'woo-usn[customer-list-by-id]', array(
            'type'        => 'text',
            'return'      => true,
            'input_class' => array( 'woousn-query' ),
            'placeholder' => __( 'separate the order ID by commas', 'ultimate-sms-notifications' ),
        ), $customer_list_by_id ),
        ),
            array(
            'label'       => __( 'Relationship between Extraction Rules types ', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'tr_class'    => 'woo-usn-customer-list-dynamic',
            'content'     => homescript_input_fields( 'woo-usn[customer-list-relationship]', array(
            'type'        => 'select',
            'required'    => true,
            'options'     => $customer_list_relationship,
            'label_class' => 'woo_usn_bs_label',
            'return'      => true,
        ), $customer_list_relationship_selected ),
        ),
            array(
            'label'       => __( 'Extraction Rules types :', 'ultimate-sms-notifications' ),
            'label_class' => 'woo-usn-table-label',
            'tr_class'    => 'woo-usn-customer-list-dynamic',
            'description' => __( 'How would you like to get order(s) that contain(s) data related to the customer(s) you want to include  into the list?', 'ultimate-sms-notifications' ),
            'content'     => "<p id='woousn-custom-fields-block'></p>",
        ),
            array(
            'label_class' => 'woo-usn-table-label',
            'content'     => "<div style='display:flex;' class='woousn-search-customers'>" . get_submit_button(
            __( 'Add Rule', 'ultimate-sms-notifications' ),
            'primary',
            'submit',
            false,
            array(
            'id' => 'woousn_add_custom_filters',
        )
        ) . '&nbsp;' . get_submit_button(
            __( 'Search Customers', 'ultimate-sms-notifications' ),
            'primary',
            'submit',
            false,
            array(
            'id' => 'woousn_search',
        )
        ) . ' &nbsp;</div>',
        )
        );
        homescript_input_table( 'contact-list-builder', apply_filters( 'woo_usn_contact_list_sender_options', $table_args ) );
        ?>
			<br/>
			<div class="woousn-cl-loader" style="display: none;"></div>
			<div class="woousn-search-list">
			</div>
		</form>
		<?php 
    }
    
    /**
     * Display metabox for sending message from the orders.
     */
    public static function message_from_orders_metabox()
    {
        $options = get_option( 'woo_usn_options' );
        if ( isset( $options['woo_usn_messages_from_orders'] ) && 1 === $options['woo_usn_messages_from_orders'] ) {
            add_meta_box(
                'woo_usn_send_messages',
                __( 'Send SMS', 'ultimate-sms-notifications' ),
                __CLASS__ . '::message_box_for_orders',
                'shop_order',
                'side',
                'high'
            );
        }
    }
    
    /**
     * Display a message box who allows shop owner/manager to send SMS
     * directly from customer orders.
     *
     * @param object $order_id WooCommerce Order ID.
     */
    public static function message_box_for_orders( $order_id )
    {
        $order = new WC_Order( $order_id );
        $id = $order->get_id();
        $order_status = $order->get_status();
        homescript_input_fields( 'woo_usn_messages_to_send', array(
            'type'        => 'textarea',
            'required'    => true,
            'input_class' => array( 'woo_usn_messages_to_send', 'woousn-textarea' ),
            'placeholder' => __( 'Type your message here.', 'ultimate-sms-notifications' ),
            'maxlength'   => 160,
        ) );
        ?>
		<input type="submit" name="woo_usn_sms_submit" id="woo_usn_sms_submit" class="button button-primary"
			value="<?php 
        esc_html_e( 'Send', 'ultimate-sms-notifications' );
        ?>" style="width:80px; word-wrap: break-word;">
		<br/>
		<br/>
		<textarea id="phone_number" class="woousn-textarea" maxlength='160' order_id='<?php 
        echo  esc_attr( $id ) ;
        ?>'
			order_status='<?php 
        echo  esc_attr( $order_status ) ;
        ?>' rows="5"
			style="display : none; height:83px; width : 254px;" readonly></textarea>
		<br/>
		<div class="woousn-cl-loader" style="display: none;"></div>
		<?php 
    }

}