<?php

/**
 * Class responsible to send SMS.
 *
 * @author Emmanuel ADEKPLOVI <emmanuel.adekplovi@homescriptone.com>
 */
class Woo_Usn_Bulk_Sms {

	/**
	 * Bulk SMS ID
	 *
	 * @var string
	 */
	private $post_id;

	/**
	 * Today date
	 *
	 * @var string
	 */
	private $today_date;

	/**
	 * This method allow to retrieve the bulk SMS ID.
	 *
	 * @return string
	 */
	public function get_id() {
		return $this->post_id;
	}

	/**
	 * This method allow to set the Bulk SMS ID.
	 *
	 * @param string $post_id Bulk SMS ID.
	 * @return void
	 */
	private function set_id( $post_id ) {
		$this->post_id = $post_id;
	}

	/**
	 * This method allow to get today date.
	 *
	 * @return string
	 */
	private function get_today_date() {
		return $this->today_date;
	}

	/**
	 * This method allows to set the today date.
	 *
	 * @param string $date Today date.
	 * @return void
	 */
	private function set_today_date( $date ) {
		$this->today_date = $date;
	}

	/**
	 * Class constructor
	 *
	 * @param string $bulk_sms_id Bulk SMS ID.
	 */
	public function __construct( $bulk_sms_id ) {
		$this->set_today_date( gmdate( 'Y-m-d H:i' ) );
		$this->set_id( $bulk_sms_id );
	}

	/**
	 * This method allows to retrieve the CPT object.
	 *
	 * @param string $post_meta_option_name Retrieve the data from the db.
	 * @return mixed
	 */
	private function get_bulk_post_object( $post_meta_option_name ) {
		return get_post_meta( $this->get_id(), $post_meta_option_name, true );
	}

	/**
	 * This method allows to get the bulk sms data.
	 *
	 * @return mixed
	 */
	private function get_bulk_sms_data() {
		$bulk_sms_data = $this->get_bulk_post_object( 'woo-usn-bulk-data' );
		return $bulk_sms_data;
	}


	/**
	 * This function allows to get the Bulk SMS status.
	 *
	 * @return string
	 */
	public function get_bulk_sms_status() {
		$bulk_sms_obj = $this->get_bulk_sms_data();
		if ( '' != $bulk_sms_obj['bulk-sms-status'] ) {
			return $bulk_sms_obj['bulk-sms-status'];
		}
		return 'stopped';
	}


	/**
	 * This method determine if the bulk sms is allowed to send SMS today.
	 *
	 * @return boolean
	 */
	public function is_allowed_to_send_bs_today() {
		return $this->check_date_validity( $this->today_date );
	}

	/**
	 * This method determine if the data provided is between the start and end of
	 * sending bulk sms.
	 *
	 * @param mixed $date_to_check Date to use for verification.
	 * @return mixed
	 */
	public function check_date_validity( $date_to_check ) {
		global $usn_utility;
		$bulk_sms_data          = $this->get_bulk_sms_data();
		$bulk_sms_start_sending = $bulk_sms_data['schedule-start-date'];
		$bulk_sms_end_sending   = $bulk_sms_data['schedule-end-date'];
		if ( $bulk_sms_start_sending && $bulk_sms_end_sending ) {
			return $usn_utility::convert_date_to_timestamp( $bulk_sms_start_sending ) <= $usn_utility::convert_date_to_timestamp( $date_to_check ) && $usn_utility::convert_date_to_timestamp( $date_to_check ) <= $usn_utility::convert_date_to_timestamp( $bulk_sms_end_sending );
		}

		if ( ! $bulk_sms_start_sending && $bulk_sms_end_sending ) {
			return $usn_utility::convert_date_to_timestamp( $date_to_check ) <= $usn_utility::convert_date_to_timestamp( $bulk_sms_end_sending );
		}
		if ( $bulk_sms_start_sending && ! $bulk_sms_end_sending ) {
			return $usn_utility::convert_date_to_timestamp( $bulk_sms_start_sending ) <= $usn_utility::convert_date_to_timestamp( $date_to_check );
		}

		return true;
	}

	/**
	 * This method allow to retrieve the periodicity for sending the bulk SMS.
	 *
	 * @return string
	 */
	public function get_schedule_type() {
		$bulk_sms_data          = $this->get_bulk_sms_data();
		$bulk_sms_schedule_type = $bulk_sms_data['schedule-sms'];
		return $bulk_sms_schedule_type;
	}


}
