<?php

/**
 * Class related to the Contact list data.
 */
class Woo_Usn_Customer_List {

	/**
	 * AJAX method to get all customer phone numbers.
	 *
	 * @return void
	 */
	public static function get_customer_details() {
		$cl_list     = array();
		$posted_data = filter_input_array( INPUT_POST );
		$security    = $posted_data['security'];

		if ( wp_verify_nonce( $security, 'woo-usn-ajax-nonce' ) ) {
			$args = $posted_data['data'];

			if ( isset( $args['customer-list-search-type'] ) && 'by-id' === $args['customer-list-search-type'] ) {
				$order_ids = $args['customer-list-by-id'];
				$cl_ids    = explode( ',', $order_ids );
			} else {
				$cl_ids = self::decode_customer_list_query( $args );
			}


			foreach ( $cl_ids as $order_id ) {
				$wc_obj = wc_get_order( $order_id );
				if ( $wc_obj ) {
					$customer_full_name             = $wc_obj->get_formatted_billing_full_name();
					$customer_country_code          = Woo_Usn_Utility::get_country_town_code( $wc_obj->get_billing_country() );
					$customer_phone_number          = $wc_obj->get_billing_phone();
					$splited_customer_phone_numbers = Woo_Usn_Utility::get_right_phone_numbers( $customer_country_code, $customer_phone_number );
					$cl_list[ $customer_full_name ] = array(
						'country'      => $customer_country_code,
						'phone_number' => $splited_customer_phone_numbers,
					);
				}
			}
		}
		$customer_numbers = '<strong>' . count( $cl_list ) . __( ' customer(s) found', 'ultimate-sms-notifications' ) . '</strong> : ';
		foreach ( $cl_list as $key => $value ) {
			if ( is_array( $key ) || is_array( $value['country'] ) ) {
				continue;
			}
			$customer_numbers .= '{ <strong>' . $key . ' (' . $value['country'] . ') </strong> - ( ' . $value['phone_number'] . ' ) }, ';
		}

		Woo_Usn_UI_Fields::format_html_fields( $customer_numbers );

		wp_die();
	}

	/**
	 * This method allows to retrieve data related to the contact list provided.
	 *
	 * @param string $id CL ID.
	 * @return mixed
	 */
	public static function get_customer_details_from_id( $id ) {
		$args = get_post_meta( $id, 'woo-usn-customer-list', true );
		if ( isset( $args['customer-list-search-type'] ) && 'by-id' === $args['customer-list-search-type'] ) {
			$customer_list_by_id = $args['customer-list-by-id'];
			$customer_data       = explode( ',', $customer_list_by_id );
		} else {
			$customer_data = self::decode_customer_list_query( $args );
		}
		return $customer_data;
	}


	/**
	 * This method query data directly into MySQL databases.
	 *
	 * @param array $args
	 * @return mixed
	 */
	public static function decode_customer_list_query( $args ) {
		global $wpdb;
		$order_id              = array();
		$relationship_operator = $args['customer-list-relationship'];

		foreach ( $args as $key => $value ) {
			if ( 'string' === gettype( $value ) ) {
				continue;
			}
			$customer_list_rules  = $value['cl-rules'];
			$customer_list_values = array();
			if ( isset( $value['cl-values'] ) ) {
				$customer_list_values = $value['cl-values'];
			}
			$customer_list_options = $value['cl-options'];
			switch ( $customer_list_rules ) {
				case 'shop_order':
					if ( empty( $customer_list_values ) ) {
						$customer_list_values = array();
					}
					$wc_order_types     = join( "','", $customer_list_values );
					$wc_query_operators = strtoupper( $customer_list_options );
					$results            = $wpdb->get_results( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type='" . $customer_list_rules . "' and post_status " . $wc_query_operators . ' ( %s ) ', $wc_order_types ) );
					if ( count( $order_id ) == 0 ) {
						$order_id = array_map(
							function( $data ) {
								return $data->ID;
							},
							(array) $results
						);
					} else {
						$old_id   = $order_id;
						$order_id = array_intersect(
							$old_id,
							array_map(
								function( $data ) {
									return $data->ID;
								},
								(array) $results
							)
						);
					}
					break;

				case '_payment_method':
				case '_shipping_method':
				case '_billing_country':
				case '_shipping_country':
					if ( empty( $customer_list_values ) ) {
						$customer_list_values = array();
					}
					$wc_order_types     = join( "','", $customer_list_values );
					$wc_query_operators = strtoupper( $customer_list_options );
					if ( $wc_query_operators !== 'IN' ) {
						$wc_query_operators = 'NOT IN';
					}
					$results  = $wpdb->get_results( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key = '" . $customer_list_rules . "' and meta_value " . $wc_query_operators . ' ( %s )', $wc_order_types ) );
					$order_id = self::get_orders_ids( $order_id, $results, $relationship_operator );
					break;

				case '_order_total':
				case '_order_tax':
				case '_order_shipping':
				case '_order_shipping_tax':
					$results  = $wpdb->get_results( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key = '" . $customer_list_rules . "' and meta_value " . $customer_list_options . ' ' . $customer_list_values );
					$order_id = self::get_orders_ids( $order_id, $results, $relationship_operator );
					break;

				case '_billing_email':
					$order_status_type = join( "%','%", explode( ',', $customer_list_values ) );
					if ( $customer_list_options !== 'in' ) {
						$customer_list_options = 'NOT LIKE';
					} else {
						$customer_list_options = 'LIKE';
					}
					// phpcs:disable WordPress.DB.PrepareSQL.NotPrepared 
					$results  = $wpdb->get_results( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key = '" . $customer_list_rules . "' and meta_value " . $customer_list_options . " ( '%" . $order_status_type . "%') " );
					$order_id = self::get_orders_ids( $order_id, $results, $relationship_operator );
					break;

				default:
					break;

			}
		}
		return $order_id;
	}

	public static function get_all_customers_lists() {
		$all_lists = get_posts(
			array(
				'numberposts' => -1,
				'post_status' => apply_filters( 'woo_usn_filter_post_status', array( 'publish' ) ),
				'post_type'   => 'woo_usn-list',
			)
		);
		$lists     = array();
		foreach ( $all_lists as $post ) {
			$lists[ $post->ID ] = $post->post_title;
		}
		return $lists;
	}

	/**
	 * This function filter the orders gotten from the wpdb query.
	 *
	 * @param array  $order_ids Array of order id.
	 * @param array  $sql_query Array of results gotten from the query.
	 * @param string $relationship_operator operator used for the query.
	 * @return array Array of order ids.
	 */
	public static function get_orders_ids( $order_ids, $sql_query, $relationship_operator = 'and' ) {
		if ( count( $order_ids ) == 0 ) {
			$order_id = array_map(
				function( $data ) {
					return $data->post_id;
				},
				(array) $sql_query
			);
		} else {
			$old_id = $order_ids;
			if ( 'and' !== $relationship_operator ) {
				$order_id = array_merge(
					$old_id,
					array_map(
						function( $data ) {
							return $data->post_id;
						},
						(array) $sql_query
					)
				);
			} else {
				$order_id = array_intersect(
					$old_id,
					array_map(
						function( $data ) {
							return $data->post_id;
						},
						(array) $sql_query
					)
				);
			}
		}
		return $order_id;

	}



}
