<?php

/**
 * This class is responible of sending Bulk SMS to multiple numbers.
 */
class Woo_Usn_Scheduler
{
    /**
     * This method give the ability to send bulk sms by using bulk sms ID.
     * This method allows is used by scheduler to send SMS at the right moment.
     *
     * @param string $post_id Bulk SMS ID.
     * @return void
     */
    public static function send_sms_to_bulk_sms( $post_id )
    {
        $bs_object = new Woo_Usn_Bulk_Sms( $post_id );
        $bs_status = $bs_object->get_bulk_sms_status();
        
        if ( 'started' === $bs_status ) {
            $must_be_sent = $bs_object->is_allowed_to_send_bs_today();
            if ( !as_next_scheduled_action( 'woo_usn_schedule_sms', array(
                'post_id' => $post_id,
            ) ) ) {
                
                if ( $must_be_sent ) {
                    $bulk_sms_schedule_type = $bs_object->get_schedule_type();
                    self::send_sms( $post_id );
                    
                    if ( 'once' === $bulk_sms_schedule_type ) {
                        $woousn_bulk_data = get_post_meta( $post_id, 'woo-usn-bulk-data', true );
                        $woousn_bulk_data['bulk-sms-status'] = 'stopped';
                        update_post_meta( $post_id, 'woo-usn-bulk-data', $woousn_bulk_data );
                    }
                
                } else {
                    $woousn_bulk_data = get_post_meta( $post_id, 'woo-usn-bulk-data', true );
                    $woousn_bulk_data['bulk-sms-status'] = 'stopped';
                    update_post_meta( $post_id, 'woo-usn-bulk-data', $woousn_bulk_data );
                    as_unschedule_action( 'woo_usn_schedule_sms', array(
                        'post_id' => $post_id,
                    ), 'woo_usn' );
                }
            
            }
        }
    
    }
    
    /**
     * This method initiate the bulk sms who must be sent.
     *
     * @return void
     */
    public static function init_bulk_sms_to_deliver()
    {
        // we make sure, we have a bulk sms who must be sent and then we scheduled.
        global  $usn_utility ;
        $bulk_sms = array_keys( $usn_utility::get_all_bulk_sms() );
        foreach ( $bulk_sms as $bulk_sms_id ) {
            self::send_sms_to_bulk_sms( $bulk_sms_id );
        }
    }
    
    /**
     * This method allows to send SMS by taking in parameter the bulk sms id.
     *
     * @param string $key Bulk SMS ID.
     * @return void
     */
    public static function send_sms( $key )
    {
        global  $usn_utility, $usn_cl ;
        $bulk_sms_obj = get_post_meta( $key, 'woo-usn-bulk-data', true );
        
        if ( isset( $bulk_sms_obj ) ) {
            $new_post = array(
                'post_title'  => get_the_title( $key ) . __( ' sent the ', 'ultimate-sms-notifications' ) . strftime( '%d %m %Y' . __( ' at ', 'ultimate-sms-notifications' ) . '%H:%m' ) . __( ' Analytics', 'ultimate-sms-notifications' ),
                'post_status' => 'publish',
                'post_author' => get_current_user(),
                'post_type'   => 'woo_usn-stats',
            );
            $post_id = wp_insert_post( $new_post );
            // get the contact list id.
            $customer_list_id = $bulk_sms_obj['bulk-sms-receivers'];
            // create a logger file, in case an error occured.
            $wc_log = new WC_Logger();
            // get the list of messages to send.
            $message_to_send = $bulk_sms_obj['messages-to-send'];
            // get all the numbers associated to the contact list.
            $customer_phone_numbers = $usn_cl::get_customer_details_from_id( $customer_list_id );
            $bulk_sms_operations = array();
            if ( isset( $customer_phone_numbers ) ) {
                // loop on all phones numbers.
                foreach ( $customer_phone_numbers as $customer_id ) {
                    $wc_obj = wc_get_order( $customer_id );
                    $phone_number = $wc_obj->get_billing_phone();
                    $customer_real_id = $wc_obj->get_customer_id();
                    $country = $wc_obj->get_billing_country();
                    $country_code = $usn_utility::get_country_town_code( $country );
                    $pn_w_cc = $usn_utility::get_right_phone_numbers( $country_code, $phone_number );
                    $phone_number = $country_code . $pn_w_cc;
                    /**
                     * Date TimeStamp Variables.
                     */
                    $current_date = getdate();
                    $year = $current_date['year'];
                    $month = $current_date['mon'];
                    $day = $current_date['mday'];
                    $hours = $current_date['hours'];
                    $minutes = $current_date['minutes'];
                    $seconds = $current_date['seconds'];
                    $timestamp = $year . $month . $day;
                    $hourstamp = $hours . $minutes . $seconds;
                    foreach ( $message_to_send as $message_id => $message ) {
                        // create an instance of sms sender.
                        $sms_obj = new Woo_Usn_SMS();
                        try {
                            $sms_obj->send_sms( $phone_number, $message );
                            $sms_status = 'success';
                        } catch ( Exception $errors ) {
                            $sms_status = 'failed';
                            $wc_log->error( 'Ultimate SMS Notifications for WooCommerce failed to send the Bulk SMS n° ' . $key . ' for the following reason : ' . $errors, array(
                                'source' => 'ultimate-sms-notifications',
                            ) );
                        }
                    }
                }
            }
        }
    
    }
    
    /**
     * We init bulk sms scheduling here.
     *
     * @return void
     */
    public static function start_scheduling()
    {
        if ( !as_next_scheduled_action( 'woo_usn_init_schedule_sms' ) ) {
            as_schedule_recurring_action(
                time(),
                2 * 5,
                'woo_usn_init_schedule_sms',
                array(),
                'woo_usn'
            );
        }
    }

}